============
Installation
============

At the command line::

    $ easy_install django_molder

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv django_molder
    $ pip install django_molder
